==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/dp.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	dp.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_DP_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. zb AT,DE',
	'MODULE_SHIPPING_DP_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_DP_COST_1_DESC' => 'Gewichtsbasierende Versandkosten der Zone 1. Z. B.: 5:16.50,10:20.50,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 16,50 für Zone 1 Versandländer.',
	'MODULE_SHIPPING_DP_COST_1_TITLE' => 'Deutsche Post Zone 1 Versandkosten',
	'MODULE_SHIPPING_DP_COST_2_DESC' => 'Gewichtsbasierende Versandkosten der Zone 2. Z. B.: 5:25.00,10:35.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 25,00 für Zone 2 Versandländer.',
	'MODULE_SHIPPING_DP_COST_2_TITLE' => 'Deutsche Post Zone 2 Versandkosten',
	'MODULE_SHIPPING_DP_COST_3_DESC' => 'Gewichtsbasierende Versandkosten der Zone 3. Z. B.: 5:29.00,10:39.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 29,50 für Zone 3 Versandländer.',
	'MODULE_SHIPPING_DP_COST_3_TITLE' => 'Deutsche Post Zone 3 Versandkosten',
	'MODULE_SHIPPING_DP_COST_4_DESC' => 'Gewichtsbasierende Versandkosten der Zone 4. Z. B.: 5:35.00,10:50.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 35,50 für Zone 4 Versandländer.',
	'MODULE_SHIPPING_DP_COST_4_TITLE' => 'Deutsche Post Zone 4 Versandkosten',
	'MODULE_SHIPPING_DP_COST_5_DESC' => 'Gewichtsbasierende Versandkosten der Zone 5. Z. B.: 5:35.00,10:50.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 35,50 für Zone 5 Versandländer.',
	'MODULE_SHIPPING_DP_COST_5_TITLE' => 'Deutsche Post Zone 5 Versandkosten',
	'MODULE_SHIPPING_DP_COST_6_DESC' => 'Gewichtsbasierende Versandkosten der Zone 6. Z. B.: E.g: 5:6.70,10:9.70,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 6,70 für Zone 6 Versandländer.',
	'MODULE_SHIPPING_DP_COST_6_TITLE' => 'Deutsche Post Zone 6 Versandkosten',
	'MODULE_SHIPPING_DP_COUNTRIES_1_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 1',
	'MODULE_SHIPPING_DP_COUNTRIES_1_TITLE' => 'Deutsche Post Zone 1 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_2_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 2',
	'MODULE_SHIPPING_DP_COUNTRIES_2_TITLE' => 'Deutsche Post Zone 2 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_3_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 3',
	'MODULE_SHIPPING_DP_COUNTRIES_3_TITLE' => 'Deutsche Post Zone 3 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_4_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 4',
	'MODULE_SHIPPING_DP_COUNTRIES_4_TITLE' => 'Deutsche Post Zone 4 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_5_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 5',
	'MODULE_SHIPPING_DP_COUNTRIES_5_TITLE' => 'Deutsche Post Zone 5 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_6_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 6',
	'MODULE_SHIPPING_DP_COUNTRIES_6_TITLE' => 'Deutsche Post Zone 6 Länder',
	'MODULE_SHIPPING_DP_HANDLING_DESC' => 'Bearbeitungsgebühr für diese Versandart in Euro',
	'MODULE_SHIPPING_DP_HANDLING_TITLE' => 'Handling Fee',
	'MODULE_SHIPPING_DP_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_DP_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_DP_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_DP_STATUS_DESC' => 'Wollen Sie den Versand über die deutsche Post anbieten?',
	'MODULE_SHIPPING_DP_STATUS_TITLE' => 'Deutsche Post WorldNet',
	'MODULE_SHIPPING_DP_TAX_CLASS_DESC' => 'Wählen Sie den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_DP_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_DP_TEXT_DESCRIPTION' => 'Deutsche Post - Weltweites Versandmodul',
	'MODULE_SHIPPING_DP_TEXT_TITLE' => 'Deutsche Post',
	'MODULE_SHIPPING_DP_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_DP_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_DP_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_DP_ZONE_DESC' => 'Wenn Sie eine Zone auswählen, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_DP_ZONE_TITLE' => 'Versand Zone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/dp.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	dp.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_DP_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. zb AT,DE',
	'MODULE_SHIPPING_DP_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_DP_COST_1_DESC' => 'Gewichtsbasierende Versandkosten der Zone 1. Z. B.: 5:16.50,10:20.50,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 16,50 für Zone 1 Versandländer.',
	'MODULE_SHIPPING_DP_COST_1_TITLE' => 'Deutsche Post Zone 1 Versandkosten',
	'MODULE_SHIPPING_DP_COST_2_DESC' => 'Gewichtsbasierende Versandkosten der Zone 2. Z. B.: 5:25.00,10:35.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 25,00 für Zone 2 Versandländer.',
	'MODULE_SHIPPING_DP_COST_2_TITLE' => 'Deutsche Post Zone 2 Versandkosten',
	'MODULE_SHIPPING_DP_COST_3_DESC' => 'Gewichtsbasierende Versandkosten der Zone 3. Z. B.: 5:29.00,10:39.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 29,50 für Zone 3 Versandländer.',
	'MODULE_SHIPPING_DP_COST_3_TITLE' => 'Deutsche Post Zone 3 Versandkosten',
	'MODULE_SHIPPING_DP_COST_4_DESC' => 'Gewichtsbasierende Versandkosten der Zone 4. Z. B.: 5:35.00,10:50.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 35,50 für Zone 4 Versandländer.',
	'MODULE_SHIPPING_DP_COST_4_TITLE' => 'Deutsche Post Zone 4 Versandkosten',
	'MODULE_SHIPPING_DP_COST_5_DESC' => 'Gewichtsbasierende Versandkosten der Zone 5. Z. B.: 5:35.00,10:50.00,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 35,50 für Zone 5 Versandländer.',
	'MODULE_SHIPPING_DP_COST_5_TITLE' => 'Deutsche Post Zone 5 Versandkosten',
	'MODULE_SHIPPING_DP_COST_6_DESC' => 'Gewichtsbasierende Versandkosten der Zone 6. Z. B.: E.g: 5:6.70,10:9.70,... Bestellgewichte größer 0kg und kleiner gleich 5kg kosten 6,70 für Zone 6 Versandländer.',
	'MODULE_SHIPPING_DP_COST_6_TITLE' => 'Deutsche Post Zone 6 Versandkosten',
	'MODULE_SHIPPING_DP_COUNTRIES_1_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 1',
	'MODULE_SHIPPING_DP_COUNTRIES_1_TITLE' => 'Deutsche Post Zone 1 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_2_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 2',
	'MODULE_SHIPPING_DP_COUNTRIES_2_TITLE' => 'Deutsche Post Zone 2 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_3_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 3',
	'MODULE_SHIPPING_DP_COUNTRIES_3_TITLE' => 'Deutsche Post Zone 3 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_4_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 4',
	'MODULE_SHIPPING_DP_COUNTRIES_4_TITLE' => 'Deutsche Post Zone 4 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_5_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 5',
	'MODULE_SHIPPING_DP_COUNTRIES_5_TITLE' => 'Deutsche Post Zone 5 Länder',
	'MODULE_SHIPPING_DP_COUNTRIES_6_DESC' => 'Kommagetrennte Auflistung von 2-Zeichen ISO-Länder Codes in Zone 6',
	'MODULE_SHIPPING_DP_COUNTRIES_6_TITLE' => 'Deutsche Post Zone 6 Länder',
	'MODULE_SHIPPING_DP_HANDLING_DESC' => 'Bearbeitungsgebühr für diese Versandart in Euro',
	'MODULE_SHIPPING_DP_HANDLING_TITLE' => 'Handling Fee',
	'MODULE_SHIPPING_DP_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_DP_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_DP_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_DP_STATUS_DESC' => 'Willst du den Versand über die deutsche Post anbieten?',
	'MODULE_SHIPPING_DP_STATUS_TITLE' => 'Deutsche Post WorldNet',
	'MODULE_SHIPPING_DP_TAX_CLASS_DESC' => 'Wähle den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_DP_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_DP_TEXT_DESCRIPTION' => 'Deutsche Post - Weltweites Versandmodul',
	'MODULE_SHIPPING_DP_TEXT_TITLE' => 'Deutsche Post',
	'MODULE_SHIPPING_DP_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_DP_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_DP_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_DP_ZONE_DESC' => 'Wenn du eine Zone auswählst, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_DP_ZONE_TITLE' => 'Versand Zone'
);
